function [F, J, H] = funUnder(x)
%FUNUNDER generates a simple underdetermined nonlinear problem
%   [F, J, H] = funUnder(x)
%   where
%      x - input vector
%   and
%      F - nonlinear function
%      J - Jacobian matrix
%      H - Hessian matrix

%   F. Pes and G. Rodriguez
%   University of Cagliari, Italy

% Last revised June 01, 2020

a = 1/9; b = 1/9;
% a = 1; b = 1/10;

F = ((a*(x(1)-1).^2 + b*(x(2)-1).^2 - 1).^2);

if nargout>1
	J = [4*a*(x(1)-1)*(a*(x(1)-1).^2+b*(x(2)-1).^2 -1), 4*b*(x(2)-1)*(a*(x(1)-1).^2+b*(x(2)-1).^2 -1)];
end

if nargout>2
	H = [12*a^2*(x(1)-1).^2+4*a*b*(x(2)-1).^2-4*a 8*a*b*(x(1)-1).*(x(2)-1); ...
		8*a*b*(x(1)-1).*(x(2)-1) 4*a*b*(x(1)-1).^2+12*b^2*(x(2)-1).^2-4*b];
end
